@@ -25,25 +25,24 @@
 #include "kcmultidialog.h"
 #include "kcmultidialog_p.h"
 
-#include <QtCore/QStringList>
-#include <QtCore/QProcess>
-#include <QtCore/QUrl>
-#include <QDesktopServices>
-#include <QPushButton>
-
-#include <kauthorized.h>
-#include <kguiitem.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <kpagewidgetmodel.h>
-#include <QDebug>
-#include <kmessagebox.h>
-
-#include "kauthaction.h"
-#include "kauthobjectdecorator.h"
-
 #include "kcmoduleproxy.h"
 
+#include <QDebug>
+#include <QDesktopServices>
+#include <QProcess>
+#include <QPushButton>
+#include <QScrollArea>
+#include <QStringList>
+#include <QUrl>
+
+#include <KAuthAction>
+#include <KAuthObjectDecorator>
+#include <KGuiItem>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KPageWidgetModel>
+
 bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
     Q_Q(KCMultiDialog);
@@ -86,7 +85,7 @@ void KCMultiDialogPrivate::_k_slotCurrentPageChanged(KPageWidgetItem *current, K
     q->blockSignals(true);
     q->setCurrentPage(previous);
 
-    KCModuleProxy *previousModule = 0;
+    KCModuleProxy *previousModule = nullptr;
     for (int i = 0; i < modules.count(); ++i) {
         if (modules[ i ].item == previous) {
             previousModule = modules[ i ].kcm;
@@ -108,7 +107,7 @@ void KCMultiDialogPrivate::_k_clientChanged()
     Q_Q(KCMultiDialog);
     // qDebug();
     // Get the current module
-    KCModuleProxy *activeModule = 0;
+    KCModuleProxy *activeModule = nullptr;
     for (int i = 0; i < modules.count(); ++i) {
         if (modules[ i ].item == q->currentPage()) {
             activeModule = modules[ i ].kcm;
@@ -408,26 +407,34 @@ KPageWidgetItem *KCMultiDialog::addModule(const QString &path, const QStringList
 
     KService::Ptr service = KService::serviceByStorageId(complete);
 
-    return addModule(KCModuleInfo(service), 0, args);
+    return addModule(KCModuleInfo(service), nullptr, args);
 }
 
 KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
         KPageWidgetItem *parentItem, const QStringList &args)
 {
     if (!moduleInfo.service()) {
-        return 0;
+        return nullptr;
     }
 
     //KAuthorized::authorizeControlModule( moduleInfo.service()->menuId() ) is
     //checked in noDisplay already
     if (moduleInfo.service()->noDisplay()) {
-        return 0;
+        return nullptr;
     }
 
-    KCModuleProxy *kcm = new KCModuleProxy(moduleInfo, 0, args);
+    // Create the scroller
+    QScrollArea *moduleScroll = new QScrollArea(this);
+    // Prepare the scroll area
+    moduleScroll->setWidgetResizable(true);
+    moduleScroll->setFrameStyle(QFrame::NoFrame);
+    moduleScroll->viewport()->setAutoFillBackground(false);
+
+    KCModuleProxy *kcm = new KCModuleProxy(moduleInfo, moduleScroll, args);
+    moduleScroll->setWidget(kcm);
 
     // qDebug() << moduleInfo.moduleName();
-    KPageWidgetItem *item = new KPageWidgetItem(kcm, moduleInfo.moduleName());
+    KPageWidgetItem *item = new KPageWidgetItem(moduleScroll, moduleInfo.moduleName());
 
     if (kcm->realModule() && kcm->realModule()->useRootOnlyMessage()) {
         item->setHeader(QStringLiteral("<b>") +
